package org.shirdrn.document.processor.analyzer;

import com.xoado.domain.util.WordUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.shirdrn.document.processor.common.DocumentAnalyzer;
import org.shirdrn.document.processor.common.Term;
import org.shirdrn.document.processor.config.Configuration;

import java.io.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class IctclasAnalyzer extends AbstractDocumentAnalyzer implements DocumentAnalyzer {

	private static final Log LOG = LogFactory.getLog(IctclasAnalyzer.class);

	public IctclasAnalyzer(Configuration configuration) {
		super(configuration);
	}

	@Override
	public Map<String, Term> analyze(File file) {
		String doc = file.getAbsolutePath();
		LOG.info("Process document: file=" + doc);
		Map<String, Term> terms = new HashMap<String, Term>(0);
		BufferedReader br = null;
		try {
			br = new BufferedReader(new InputStreamReader(new FileInputStream(file), charSet));
			String line = null;
			while((line = br.readLine()) != null) {
				line = line.trim();
				if(!line.isEmpty()) {

					List nlpSeg = WordUtil.getNlpSeg(line);
					StringBuffer content = new StringBuffer();
					for(Object rawWord : nlpSeg) {
						String[] words = String.valueOf(rawWord).split("/");
						if(words.length == 2) {
							String word = words[0];
							String lexicalCategory = words[1];
							Term term = terms.get(word);
							if(term == null) {
								term = new Term(word);
								// TODO set lexical category
								term.setLexicalCategory(lexicalCategory);
								terms.put(word, term);
							}
							term.incrFreq();
							LOG.debug("Got word: word=" + rawWord);
						}
					}
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if(br != null) {
					br.close();
				}
			} catch (IOException e) {
				LOG.warn(e);
			}
		}
		return terms;
	}

}
